@@ -8,7 +8,7 @@ package Excel::Writer::XLSX::Chart::Scatter;
 #
 # See formatting note in Excel::Writer::XLSX::Chart.
 #
-# Copyright 2000-2024, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2025, John McNamara, jmcnamara@cpan.org
 #
 # SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
 #
@@ -24,7 +24,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 
 ###############################################################################
@@ -40,7 +40,7 @@ sub new {
     $self->{_subtype}           = $self->{_subtype} || 'marker_only';
     $self->{_cross_between}     = 'midCat';
     $self->{_horiz_val_axis}    = 0;
-    $self->{_val_axis_postion}  = 'b';
+    $self->{_val_axis_position} = 'b';
     $self->{_smooth_allowed}    = 1;
     $self->{_requires_category} = 1;
 
@@ -568,6 +568,6 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright MM-MMXXIV, John McNamara.
+Copyright MM-MMXXV, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
