@@ -6,7 +6,7 @@ package Excel::Writer::XLSX::Drawing;
 #
 # Used in conjunction with Excel::Writer::XLSX
 #
-# Copyright 2000-2024, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2025, John McNamara, jmcnamara@cpan.org
 #
 # SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
 #
@@ -23,7 +23,7 @@ use Excel::Writer::XLSX::Package::XMLwriter;
 use Excel::Writer::XLSX::Worksheet;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '1.13';
+our $VERSION = '1.15';
 
 
 ###############################################################################
@@ -270,7 +270,7 @@ sub _write_absolute_anchor {
 
     $self->xml_start_tag( 'xdr:absoluteAnchor' );
 
-    # Different co-ordinates for horizonatal (= 0) and vertical (= 1).
+    # Different co-ordinates for horizontal (= 0) and vertical (= 1).
     if ( $self->{_orientation} == 0 ) {
 
         # Write the xdr:pos element.
@@ -1589,7 +1589,7 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
-(c) MM-MMXXIV, John McNamara.
+(c) MM-MMXXV, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
 
